import sqlite3

class db:
	def __init__(self, dbname):
		self.conn = sqlite3.connect(dbname)
		self.cur = self.conn.cursor()

	def read(self, command, flat=True):
		self.cur.execute(command)
		f = self.cur.fetchall()
		if not f or not flat:
			return f
		else:
			if len(f[0]) == 1:
				f = [i[0] for i in f]
				if len(f) == 1:
					f = f[0]
			return f

	def read1(self, command):
		self.cur.execute(command)
		f = self.cur.fetchone()
		if len(f) == 1:
			f = f[0]
		return f
	
	def write(self, command):
		self.cur.execute(command)
		self.cur.commit()

	def __del__(self):
		self.conn.close()




from setuptools import setup

with open('README.txt') as file:
    long_description = file.read()

setup(name='palsql',
      version='1.1',
      description='Sqlite3 Wrapper Class',
      long_description=long_description,
      url='https://github.com/ipal0/palsql',
      author='Pal',
      author_email='ipal0can@gmail.com',
      license='GPL',
      python_requires='>=3',
      packages=['palsql'])
